@@ -2,87 +2,27 @@ package Module::Provision::TraitFor::AddingFiles;
 
 use namespace::autoclean;
 
-use Class::Usul::Constants;
-use Class::Usul::Functions  qw( classfile throw );
-use Scalar::Util            qw( blessed );
-use Unexpected::Functions   qw( Unspecified );
+use Class::Usul::Constants qw( EXCEPTION_CLASS OK );
+use Class::Usul::Functions qw( classfile throw );
+use Scalar::Util           qw( blessed );
+use Unexpected::Functions  qw( Unspecified );
 use Moo::Role;
 
 requires qw( add_to_vcs appldir binsdir exec_perms expand_tuple libdir
              loc method module_abstract next_argv output project
              render_template stash template_dir template_list testdir );
 
-# Construction
-around 'generate_metadata' => sub {
-   my ($orig, $self, @args) = @_; my $mdf = $orig->( $self, @args );
-
-   $mdf and $self->appldir->catfile( $mdf )->exists
-        and $self->add_to_vcs( $mdf );
-
-   return $mdf;
+# Private methods
+my $_program_abstract = sub {
+   return $_[ 0 ]->loc( 'One-line description of the programs purpose' );
 };
 
-# Public methods
-sub module : method {
-   my $self = shift; my $target = $self->_get_target( 'libdir', \&classfile );
-
-   $self->output( 'Adding new module' );
-   $target = $self->render_template( 'perl_module.pm', $target );
-   $self->add_to_vcs( $target, 'module' );
-   return OK;
-}
-
-sub program : method {
-   my $self = shift; my $target = $self->_get_target( 'binsdir' );
-
-   $self->output( 'Adding new program' );
-   $target = $self->render_template( 'perl_program.pl', $target );
-   chmod $self->exec_perms, $target->pathname;
-   $self->add_to_vcs( $target, 'program' );
-   return OK;
-}
-
-sub test : method {
-   my $self = shift; my $target = $self->_get_target( 'testdir' );
-
-   $self->output( 'Adding new test' );
-   $target = $self->render_template( '10test_script.t', $target );
-   $self->add_to_vcs( $target, 'test' );
-   return OK;
-}
-
-sub update_file : method {
-   my $self   = shift;
-   my $target = $self->next_argv
-      or throw class => Unspecified, args => [ 'Target' ];
-   my $index  = {};
-
-   for my $t (map { my $k = $_->[ 0 ]; my $v = $_->[ 1 ];
-                    $_->[ 1 ] = $v->relative( $self->appldir ); $_ }
-              map { my $k = $_->[ 0 ]; my $v = $_->[ 1 ];
-                    $v->is_dir and $_->[ 1 ] = $v->catfile( $k ); $_ }
-              map { $self->expand_tuple( $_ ) } @{ $self->template_list } ) {
-      $index->{ $t->[ 1 ]->pathname } = $t->[ 0 ];
-   }
-
-   exists $index->{ $target }
-      or throw error => 'File [_1] not in template map', args => [ $target ];
-
-   my $source = $self->template_dir->catfile( $index->{ $target } );
-
-   $source->exists or throw error => 'File [_1] not found', args => [ $source ];
-   $source->copy( $target );
-   return OK;
-}
-
-# Private methods
-sub _get_target {
+my $_get_target = sub {
    my ($self, $dir, $f) = @_;
 
-   my $car = $self->next_argv
-      or throw class => Unspecified, args => [ 'Target' ];
+   my $car = $self->next_argv or throw Unspecified, [ 'Target' ];
    my $abstract = $self->next_argv
-               || ($self->method eq 'program' ? $self->_program_abstract
+               || ($self->method eq 'program' ? $self->$_program_abstract
                                               : $self->module_abstract );
 
    $self->project; # Force evaluation of lazy attribute
@@ -97,10 +37,68 @@ sub _get_target {
    $self->method ne 'test' and $self->stash->{abstract} = $abstract;
 
    return $target;
+};
+
+# Construction
+around 'generate_metadata' => sub {
+   my ($orig, $self, @args) = @_; my $mdf = $orig->( $self, @args );
+
+   $mdf and $self->appldir->catfile( $mdf )->exists
+        and $self->add_to_vcs( $mdf );
+
+   return $mdf;
+};
+
+# Public methods
+sub module : method {
+   my $self = shift; my $target = $self->$_get_target( 'libdir', \&classfile );
+
+   $self->output( 'Adding new module' );
+   $target = $self->render_template( 'perl_module.pm', $target );
+   $self->add_to_vcs( $target, 'module' );
+   return OK;
 }
 
-sub _program_abstract {
-   return $_[ 0 ]->loc( 'One-line description of the programs purpose' );
+sub program : method {
+   my $self = shift; my $target = $self->$_get_target( 'binsdir' );
+
+   $self->output( 'Adding new program' );
+   $target = $self->render_template( 'perl_program.pl', $target );
+   chmod $self->exec_perms, $target->pathname;
+   $self->add_to_vcs( $target, 'program' );
+   return OK;
+}
+
+sub test : method {
+   my $self = shift; my $target = $self->$_get_target( 'testdir' );
+
+   $self->output( 'Adding new test' );
+   $target = $self->render_template( '10test_script.t', $target );
+   $self->add_to_vcs( $target, 'test' );
+   return OK;
+}
+
+sub update_file : method {
+   my $self   = shift;
+   my $target = $self->next_argv or throw Unspecified, [ 'target' ];
+   my $index  = {};
+
+   for my $t (map { my $k = $_->[ 0 ]; my $v = $_->[ 1 ];
+                    $_->[ 1 ] = $v->relative( $self->appldir ); $_ }
+              map { my $k = $_->[ 0 ]; my $v = $_->[ 1 ];
+                    $v->is_dir and $_->[ 1 ] = $v->catfile( $k ); $_ }
+              map { $self->expand_tuple( $_ ) } @{ $self->template_list } ) {
+      $index->{ $t->[ 1 ]->pathname } = $t->[ 0 ];
+   }
+
+   exists $index->{ $target }
+      or throw 'File [_1] not in template map', [ $target ];
+
+   my $source = $self->template_dir->catfile( $index->{ $target } );
+
+   $source->exists or throw 'File [_1] not found', [ $source ];
+   $source->copy( $target );
+   return OK;
 }
 
 1;
@@ -198,7 +196,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2013 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
