@@ -2,7 +2,7 @@ package Module::Provision::TraitFor::CPANDistributions;
 
 use namespace::autoclean;
 
-use Class::Usul::Constants;
+use Class::Usul::Constants   qw( EXCEPTION_CLASS FALSE NUL OK TRUE );
 use Class::Usul::Crypt::Util qw( decrypt_from_config encrypt_for_config
                                  is_encrypted );
 use Class::Usul::Functions   qw( ensure_class_loaded io throw );
@@ -19,69 +19,11 @@ requires qw( add_leader config debug distname dist_version dumper
 
 # Private attributes
 has '_debug_http_method' => is => 'ro', isa => NonEmptySimpleStr,
-   builder               => '_build__debug_http_method', init_arg => undef;
-
-# Public methods
-sub cpan_upload : method {
-   my $self = shift; my $ver = $self->next_argv; my $file;
-
-   if ($ver) { $file = $self->distname."-${ver}.tar.gz" }
-   else {
-      $file = $self->distname.'-'.$self->dist_version.'.tar.gz';
-      -f $file or $file = $self->distname.'-v'.$self->dist_version.'.tar.gz';
-   }
-
-   -f $file or throw class => PathNotFound, args => [ $file ];
-
-   ensure_class_loaded( 'CPAN::Uploader' );
-
-   my $args   = $self->_read_rc_file; $args->{subdir} //= lc $self->distname;
-   my $prompt = $self->add_leader( $self->loc( 'Really upload to CPAN' ) );
-
-   exists $args->{dry_run}
-       or $args->{dry_run} = not $self->yorn( $prompt, FALSE, TRUE, 0 );
-
-   CPAN::Uploader->upload_file( $file, $args );
-   return OK;
-}
-
-sub delete_cpan_files : method {
-   my $self   = shift;
-   my $args   = $self->_read_rc_file; $args->{subdir} //= lc $self->distname;
-   my $files  = $self->_convert_versions_to_paths( $self->extra_argv, $args );
-   my $prompt = $self->loc( 'Really delete files from CPAN' );
-      $prompt = $self->add_leader( $prompt );
-
-   exists $args->{dry_run}
-       or $args->{dry_run} = not $self->yorn( $prompt, FALSE, TRUE, 0 );
-
-   if ($args->{dry_run}) {
-      $self->output( 'By request, cowardly refusing to do anything at all' );
-      $self->output( "The following would have been used to delete files:\n" );
-      $self->dumper( $args  );
-      $self->dumper( $files );
-   }
-   else { $self->_delete_files( $files, $args ) }
-
-   return OK;
-}
-
-sub set_cpan_password : method {
-   my $self = shift; my $args = $self->_read_rc_file;
-
-   $args->{password} = $self->next_argv
-      or throw class => Unspecified, args  => [ 'password' ];
-   $self->_write_rc_file( $args );
-   return OK;
-}
+   builder               => sub { $ENV{CPAN_DELETE_FILES_DISPLAY_HTTP_BODY}
+                                  ? 'as_string' : 'headers_as_string' };
 
 # Private methods
-sub _build__debug_http_method {
-   return $ENV{CPAN_DELETE_FILES_DISPLAY_HTTP_BODY}
-        ? 'as_string' : 'headers_as_string';
-}
-
-sub _convert_versions_to_paths {
+my $_convert_versions_to_paths = sub {
    my ($self, $versions, $args) = @_; my $paths = []; $args ||= {};
 
    my $distname = $self->distname;
@@ -94,47 +36,9 @@ sub _convert_versions_to_paths {
    }
 
    return $paths;
-}
+};
 
-sub _delete_files {
-   my ($self, $files, $args) = @_; my $target = $args->{target} || 'PAUSE';
-
-   $self->info( 'Registering to delete files with the [_1] web server',
-                { args => [ $target ] } );
-
-   ensure_class_loaded( 'LWP::UserAgent' );
-
-   my $agent   = LWP::UserAgent->new;
-
-   $agent->agent( $self->_ua_string ); $agent->env_proxy;
-   $args->{http_proxy} and $agent->proxy( http => $args->{http_proxy} );
-
-   my $uri     = $args->{delete_files_uri} || $self->config->delete_files_uri;
-   my $request = $self->_get_delete_request( $files, $args, $uri );
-
-   $self->info( 'POSTing delete files request to [_1]', { args => [ $uri ] } );
-   $self->_throw_on_error( $uri, $target, $agent->request( $request ) );
-   return;
-}
-
-sub _get_delete_request {
-   my ($self, $files, $args, $uri) = @_;
-
-   my @body = ( HIDDENNAME => $args->{user},
-                SUBMIT_pause99_delete_files_delete => 'Delete', );
-
-   for my $file (@{ $files }) {
-      push @body, 'pause99_delete_files_FILE', $file;
-   }
-
-   my $request = POST( $uri, \@body );
-
-   $request->authorization_basic( $args->{user}, $args->{password} );
-   $self->_log_http_debug( 'REQUEST', $request );
-   return $request;
-}
-
-sub _log_http_debug {
+my $_log_http_debug = sub {
    my ($self, $type, $obj, $msg) = @_; $self->debug or return;
 
    my $method = $self->_debug_http_method;
@@ -144,9 +48,9 @@ sub _log_http_debug {
                                           $obj->$method()."\n",
                                  "----- ${type} END -------\n" );
    return;
-}
+};
 
-sub _read_rc_file {
+my $_read_rc_file = sub {
    my $self = shift; my $dir = $self->config->my_home; my $attr = {};
 
    for (io( [ $dir, '.pause' ] )->chomp->getlines) {
@@ -161,56 +65,147 @@ sub _read_rc_file {
 
    my $pword; exists $attr->{password}
       and $pword = $attr->{password}
-      and is_encrypted( $pword )
-      and $attr->{password} = decrypt_from_config( $self->config, $pword );
+      and is_encrypted $pword
+      and $attr->{password} = decrypt_from_config $self->config, $pword;
 
    return $attr;
-}
+};
 
-sub _throw_on_error {
-   my ($self, $uri, $target, $response) = @_;
-
-   defined $response
-      or throw error => 'Request completely failed - we got undef back: [_1]',
-               args  => [ $OS_ERROR ];
-
-   if ($response->is_error) {
-      my $class = blessed $self || $self;
-
-      $response->code == RC_NOT_FOUND and throw error =>
-         "PAUSE's CGI for handling messages seems to have moved!\n".
-         "(HTTP response code of 404 from the [_1] web server)\n".
-         "It used to be: [_2]\nPlease inform the maintainer of [_3]\n",
-         args => [ $target, $uri, $class ];
-
-      throw error => "Request failed error code [_1]\n  Message: [_2]\n",
-            args  => [ $response->code, $response->message ];
-   }
-
-   $self->_log_http_debug( 'RESPONSE', $response, 'Looks OK!' );
-   $self->info( '[_1] delete request sent ok [[_2]]',
-                { args => [ $target, $response->code ] } );
-   return;
-}
-
-sub _ua_string {
+my $_ua_string = sub {
    my $self  = shift;
    my $class = blessed $self || $self;
    my $ver   = $class->VERSION // 'dev';
 
    return "${class}/${ver}";
-}
+};
 
-sub _write_rc_file {
+my $_write_rc_file = sub {
    my ($self, $attr) = @_;
 
    my $file = $self->config->my_home->catfile( '.pause' );
 
-   $attr->{password} = encrypt_for_config( $self->config, $attr->{password} );
+   $attr->{password} = encrypt_for_config $self->config, $attr->{password};
 
    $file->println( "${_} ".$attr->{ $_ } ) for (sort keys %{ $attr });
 
    return;
+};
+
+my $_get_delete_request = sub {
+   my ($self, $files, $args, $uri) = @_;
+
+   my @body = ( HIDDENNAME => $args->{user},
+                SUBMIT_pause99_delete_files_delete => 'Delete', );
+
+   for my $file (@{ $files }) {
+      push @body, 'pause99_delete_files_FILE', $file;
+   }
+
+   my $request = POST( $uri, \@body );
+
+   $request->authorization_basic( $args->{user}, $args->{password} );
+   $self->$_log_http_debug( 'REQUEST', $request );
+   return $request;
+};
+
+my $_throw_on_error = sub {
+   my ($self, $uri, $target, $response) = @_;
+
+   defined $response
+      or throw 'Request completely failed - we got undef back: [_1]',
+               [ $OS_ERROR ];
+
+   if ($response->is_error) {
+      my $class = blessed $self || $self;
+
+      $response->code == RC_NOT_FOUND and throw
+         "PAUSE's CGI for handling messages seems to have moved!\n".
+         "(HTTP response code of 404 from the [_1] web server)\n".
+         "It used to be: [_2]\nPlease inform the maintainer of [_3]\n",
+         [ $target, $uri, $class ];
+
+      throw "Request failed error code [_1]\n  Message: [_2]\n",
+            [ $response->code, $response->message ];
+   }
+
+   $self->$_log_http_debug( 'RESPONSE', $response, 'Looks OK!' );
+   $self->info( '[_1] delete request sent ok [[_2]]',
+                { args => [ $target, $response->code ] } );
+   return;
+};
+
+my $_delete_files = sub {
+   my ($self, $files, $args) = @_; my $target = $args->{target} || 'PAUSE';
+
+   $self->info( 'Registering to delete files with the [_1] web server',
+                { args => [ $target ] } );
+
+   ensure_class_loaded( 'LWP::UserAgent' );
+
+   my $agent   = LWP::UserAgent->new;
+
+   $agent->agent( $self->$_ua_string ); $agent->env_proxy;
+   $args->{http_proxy} and $agent->proxy( http => $args->{http_proxy} );
+
+   my $uri     = $args->{delete_files_uri} || $self->config->delete_files_uri;
+   my $request = $self->$_get_delete_request( $files, $args, $uri );
+
+   $self->info( 'POSTing delete files request to [_1]', { args => [ $uri ] } );
+   $self->$_throw_on_error( $uri, $target, $agent->request( $request ) );
+   return;
+};
+
+# Public methods
+sub cpan_upload : method {
+   my $self = shift; my $ver = $self->next_argv; my $file;
+
+   if ($ver) { $file = $self->distname."-${ver}.tar.gz" }
+   else {
+      $file = $self->distname.'-'.$self->dist_version.'.tar.gz';
+      -f $file or $file = $self->distname.'-v'.$self->dist_version.'.tar.gz';
+   }
+
+   -f $file or throw PathNotFound, [ $file ];
+
+   ensure_class_loaded( 'CPAN::Uploader' );
+
+   my $args   = $self->$_read_rc_file; $args->{subdir} //= lc $self->distname;
+   my $prompt = $self->add_leader( $self->loc( 'Really upload to CPAN' ) );
+
+   exists $args->{dry_run}
+       or $args->{dry_run} = not $self->yorn( $prompt, FALSE, TRUE, 0 );
+
+   CPAN::Uploader->upload_file( $file, $args );
+   return OK;
+}
+
+sub delete_cpan_files : method {
+   my $self   = shift;
+   my $args   = $self->$_read_rc_file; $args->{subdir} //= lc $self->distname;
+   my $files  = $self->$_convert_versions_to_paths( $self->extra_argv, $args );
+   my $prompt = $self->loc( 'Really delete files from CPAN' );
+      $prompt = $self->add_leader( $prompt );
+
+   exists $args->{dry_run}
+       or $args->{dry_run} = not $self->yorn( $prompt, FALSE, TRUE, 0 );
+
+   if ($args->{dry_run}) {
+      $self->output( 'By request, cowardly refusing to do anything at all' );
+      $self->output( "The following would have been used to delete files:\n" );
+      $self->dumper( $args  );
+      $self->dumper( $files );
+   }
+   else { $self->$_delete_files( $files, $args ) }
+
+   return OK;
+}
+
+sub set_cpan_password : method {
+   my $self = shift; my $args = $self->$_read_rc_file;
+
+   $args->{password} = $self->next_argv or throw Unspecified, [ 'password' ];
+   $self->$_write_rc_file( $args );
+   return OK;
 }
 
 1;
@@ -304,7 +299,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2013 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
